Experimenting with exposing SPL standard toolkit as classes and installable package for the Python Application API for IBM Streams.

Experimental versions are being uploaded to pypi

```
pip install streamsx.standard
```

The latest code be installed as the `streamsx.standard` package directly from github using:

```
pip install git+https://github.com/IBMStreams/streamsx.standard.git
```
